@@ -13,6 +13,8 @@ use std::sync::Arc;
 
 use crate::providers::Wss;
 
+use super::AnyProvider;
+
 cfg_if! {
     if #[cfg(not(target_arch = "wasm32"))] {
         use crate::providers::Tcp;
@@ -199,6 +201,19 @@ impl Addr {
             }
         }
     }
+
+    #[inline]
+    /// connect to the address
+    pub async fn bind(&self) -> Result<AnyProvider> {
+        Ok(match self {
+            Addr::Tcp(addrs) => AnyProvider::Tcp(Tcp::bind(**addrs).await?),
+            Addr::InsecureTcp(addrs) => AnyProvider::InsecureTcp(Tcp::bind(**addrs).await?),
+            Addr::Unix(addrs) => AnyProvider::Unix(Unix::bind(&**addrs).await?),
+            Addr::InsecureUnix(addrs) => AnyProvider::InsecureUnix(Unix::bind(&**addrs).await?),
+            Addr::Wss(addrs) => AnyProvider::Wss(Wss::bind(addrs.as_str()).await?),
+            Addr::InsecureWss(addrs) => AnyProvider::InsecureWss(Wss::bind(addrs.as_str()).await?),
+        })
+    }
 }
 
 impl FromStr for Addr {
